Learn R Programming

spINAR (version 0.2.0)

spINAR-package: (Semi)parametric estimation and bootstrapping of INAR models

Description

Semiparametric and parametric estimation of INAR models including a finite sample refinement for the semiparametric setting, different procedures to bootstrap INAR data and flexible simulation of INAR data.

Arguments

Semiparametric INAR Model

The package provides a flexible simulation of INAR data by inserting a user-defined pmf argument in the spinar_sim function. Using spinar_est, it allows for semiparametric estimation of the INAR model along Drost et al. (2009) and additionally, it includes a small sample refinement spinar_penal (Faymonville et al., 2022) together with a validation of the upcoming penalization parameters (spinar_penal_val). Furthermore, it contains a semiparametric INAR bootstrap procedure implemented in spinar_boot (Jentsch and Weiß, 2017).

Parametric INAR Model

In addition to the semiparametric model, the package also allows for parametric simulation (spinar_sim), parametric estimation (spinar_est_param) and parametric bootstrapping (spinar_boot) of INAR data.

Author

Maintainer: Maxime Faymonville faymonville@statistik.tu-dortmund.de (ORCID)

Authors:

Other contributors:

References

Faymonville, M., Jentsch, C., Weiß, C.H. and Aleksandrov, B. (2022). "Semiparametric Estimation of INAR Models using Roughness Penalization". Statistical Methods & Applications. tools:::Rd_expr_doi("10.1007/s10260-022-00655-0").

Jentsch, C. and Weiß, C. H. (2017), “Bootstrapping INAR Models”. Bernoulli 25(3), pp. 2359--2408. tools:::Rd_expr_doi("10.3150/18-BEJ1057").

Drost, F., Van den Akker, R. and Werker, B. (2009), “Efficient estimation of auto-regression parameters and innovation distributions for semiparametric integer-valued AR(p) models”. Journal of the Royal Statistical Society. Series B 71(2), pp. 467--485. tools:::Rd_expr_doi("10.1111/j.1467-9868.2008.00687.x").

See Also