| spinar_penal | R Documentation |
Semiparametric penalized estimation of the autoregressive parameters and the innovation distribution of INAR(p) models,
\code{p} \in \{1,2\}. The estimation is conducted by maximizing the penalized conditional likelihood of the model. If both
penalization parameters are set to zero, the function coincides to the spinar_est function of this package.
spinar_penal(x, p, penal1 = 0, penal2 = 0)
x |
[ |
p |
[ |
penal1 |
|
penal2 |
|
Vector containing the penalized estimated coefficients \code{alpha}_1,...,\code{alpha}_p and the penalized
estimated entries of the pmf \code{pmf}_0, \code{pmf}_1,... where \code{pmf}_i represents the probability of
an innovation being equal to i.
# generate data
dat1 <- spinar_sim(n = 50, p = 1, alpha = 0.5,
pmf = c(0.3, 0.25, 0.2, 0.15, 0.1))
# penalized semiparametric estimation
spinar_penal(x = dat1, p = 1, penal1 = 0, penal2 = 0.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.